@@ -3,7 +3,7 @@ from dataclasses import dataclass
 from functools import partial
 import os
 from pathlib import Path
-from typing import Any, Union
+from typing import Union
 from urllib.parse import urlparse
 from rich.style import Style
 from rich.text import Text, TextType
@@ -20,7 +20,7 @@ from textual.widgets.tree import TreeNode
 from posting.collection import Collection, RequestModel
 from posting.config import SETTINGS
 from posting.files import get_unique_request_filename
-from posting.help_screen import HelpData
+from posting.help_data import HelpData
 from posting.save_request import generate_request_filename
 from posting.widgets.collection.new_request_modal import (
     NewRequestData,
@@ -54,32 +54,35 @@ Sub-collections cannot be deleted from the UI yet.
 """,
     )
 
+    BINDING_GROUP_TITLE = "Collection Browser"
+
     BINDINGS = [
+        Binding("slash", "screen.open_request_search_palette", "Search"),
         Binding(
             "d",
             "duplicate_request",
             "Dupe",
-            # tooltip="Duplicate the request under the cursor and show the 'New Request' modal to change the name/description.",
+            tooltip="Duplicate the request under the cursor and show the 'New Request' modal to change the name/description.",
         ),
         Binding(
             "D",
             "quick_duplicate_request",
             "Quick Dupe",
             show=False,
-            # tooltip="Duplicate the request and automatically assign a unique name.",
+            tooltip="Duplicate the request and automatically assign a unique name.",
         ),
         Binding(
             "backspace",
             "delete_request_with_confirmation",
             "Delete",
-            # tooltip="Delete the request under the cursor.",
+            tooltip="Delete the request under the cursor.",
         ),
         Binding(
             "shift+backspace",
             "delete_request",
             "Delete",
             show=False,
-            # tooltip="Delete the collection under the cursor.",
+            tooltip="Delete the collection under the cursor.",
         ),
     ]
 
@@ -180,10 +183,23 @@ Sub-collections cannot be deleted from the UI yet.
             if self._cursor_node is not node:
                 node_label.stylize(Style(dim=True, bold=True))
         else:
-            method_style = getattr(
-                self.app.theme_object.method, node.data.method.lower(), "dim"
+            theme_vars = self.app.theme_variables
+            default_styles = {
+                "get": theme_vars.get("text-primary"),
+                "post": theme_vars.get("text-success"),
+                "put": theme_vars.get("text-warning"),
+                "delete": theme_vars.get("text-error"),
+                "options": theme_vars.get("text-muted"),
+                "head": theme_vars.get("text-muted"),
+            }
+
+            method = node.data.method.lower()
+            method_style = theme_vars.get(
+                f"method-{method}",
+                default_styles.get(method),
             )
-            open_indicator = "█ " if node is self.currently_open else " "
+
+            open_indicator = ">" if node is self.currently_open else " "
             method = (
                 f"{node.data.method[:3]}" if isinstance(node.data, RequestModel) else ""
             )
@@ -539,26 +555,11 @@ Sub-collections cannot be deleted from the UI yet.
 
 
 class RequestPreview(VerticalScroll):
-    DEFAULT_CSS = """\
-        RequestPreview {
-            color: $text-muted;
-            background: transparent;
-            dock: bottom;
-            height: auto;
-            max-height: 50%;
-            padding: 0 1;
-            border-top: solid $accent 35%;
-            &.hidden {
-                display: none;
-            }
-        }
-    """
-
     request: Reactive[RequestModel | None] = reactive(None)
 
     def compose(self) -> ComposeResult:
         self.can_focus = False
-        yield Static("", id="description")
+        yield Static("", markup=False, id="description")
 
     def watch_request(self, request: RequestModel | None) -> None:
         self.set_class(request is None or not request.description, "hidden")
@@ -568,26 +569,6 @@ class RequestPreview(VerticalScroll):
 
 
 class CollectionBrowser(Vertical):
-    DEFAULT_CSS = """\
-    CollectionBrowser {
-        height: 1fr;
-        dock: left;
-        width: auto;
-        max-width: 33%;
-        & Tree {
-            min-width: 20;
-            background: transparent;
-        }
-
-        #empty-collection-label {
-           color: $text-muted;
-           padding: 1 2;
-        }
-
-
-    }
-    """
-
     def __init__(
         self,
         collection: Collection | None = None,
@@ -606,7 +587,7 @@ class CollectionBrowser(Vertical):
         collection = self.collection
 
         yield Static(
-            "[i]Collection is empty.[/]\nPress [b]ctrl+s[/b] to save the current request.",
+            "[i]Collection is empty.[/]\n\nPress [b]ctrl+s[/b] to save the current request.\n\nPress [b]ctrl+h[/b] to toggle this panel.",
             id="empty-collection-label",
         )
 
